@@ -55,7 +55,7 @@ void DesktopFileScanner::run()
     foreach(const QString& file, files)
     {
         QSettings desktopFile(appShortcutDir.absoluteFilePath(file), QSettings::IniFormat);
-        qDebug() << "Parsing file " << desktopFile.fileName();
+        //qDebug() << "Parsing file " << desktopFile.fileName();
         desktopFile.beginGroup("Desktop Entry");
         if (desktopFile.value("Type").value<QString>() == "Daemon") continue;
         QString name = desktopFile.value("Name").value<QString>();
@@ -86,7 +86,7 @@ void DesktopFileScanner::run()
             xiconpath = QString();
         }
         desc = new desktopDescriptor(
-                    QFileInfo(file).completeBaseName(),
+                    file,
                     name,
                     desktopFile.value("Icon").value<QString>(),
                     xiconpath);
@@ -95,6 +95,6 @@ void DesktopFileScanner::run()
         apps.insert(name.toLower(), desc); // for
         desc->notifyChange();
     }
-    qDebug() << apps.values().count() << " .desktop files parsed ";
+    //qDebug() << apps.values().count() << " .desktop files parsed ";
     emit appListChanged();
 }
